"""
Tests for `wagtailosm` module.
"""
import pytest
from wagtailosm import wagtailosm


class TestWagtailosm(object):

    @classmethod
    def setup_class(cls):
        pass

    def test_something(self):
        pass

    @classmethod
    def teardown_class(cls):
        pass
